==> conc-0.4.tar.gz: conc-0.4/src/conc-ui.h <==
/*
 This file is part of conc.

    Conc is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Conc is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with conc; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

typedef struct {
  gchar *name;
  gint id;
  gboolean active;
  GIOChannel *to_term;
  GIOChannel *from_term;
  GtkWidget *frame;
  GtkWidget *activity;
  GtkWidget *activitybox;
  GtkWidget *last_active;
  GtkWidget *console_b;
  GtkWidget *config_b;
  GtkWidget *log_b;
  GtkWidget *console_app;
  GtkWidget *console_app_connected;
  GtkWidget *console;
  GtkWidget *log_app;
  GtkWidget *log_app_text;
  GtkAdjustment *log_app_progress_adj;
  gint log_app_insertpoint;
} Console;

typedef struct {
  gchar *identity;
  GtkWidget *app;
  GtkWidget *status;
  GtkWidget *x;
  GArray *vboxen;
  gint columns;
  GtkWidget *vbox;
  gchar *server;
  gchar *console_font;
  gint console_scrollback;
  GtkWidget *config_app;
  GtkWidget **config_app_w;
  gint config_app_server_selection;
  gint config_app_console_selection;
  GtkWidget *prefs_app;
  GtkWidget *prefs_app_new_columns;
  GtkWidget *prefs_app_new_scrollback;
  GList *prefs_app_console_list;
  gchar **prefs_app_v;
  GtkWidget *prefs_app_font;
  ConcChannel *srv_chan;
  GConfEngine *gce;
  GList *consoles;
  ConcList *console_list;
  ConcList *server_list;
  gchar *buf;
  GtkRcStyle *activity_active;
  GtkRcStyle *activity_broken;
} Globals;
extern Globals *G;

extern void conc_load_prefs(void);
extern void conc_save_prefs(void);
extern void conc_preferences(GtkWidget *widget, gpointer data);
extern void conc_add_console(Console *c);
extern void conc_remove_console(Console *c);
extern void conc_columns_new(gint newcols);
extern gint getid(gchar *p);
extern void conc_configure_edit_console(GtkButton *button,gpointer data);
extern void conc_configure(GtkWidget *widget, gpointer data);
extern void conc_configure_list_server_changed();
extern void conc_configure_list_console_changed();

==> conc-0.5.tar.gz: conc-0.5/src/conc-ui.h <==
/*
 This file is part of conc.

    Conc is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Conc is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with conc; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

typedef struct {
  gchar *name;
  gint id;
  gboolean active;
  GIOChannel *to_term;
  GIOChannel *from_term;
  GtkWidget *frame;
  GtkWidget *activity;
  GtkWidget *activitybox;
  GtkWidget *last_active;
  GtkWidget *console_b;
  GtkWidget *config_b;
  GtkWidget *log_b;
  GtkWidget *console_app;
  GtkWidget *console_app_connected;
  GtkWidget *console;
  GtkWidget *log_app;
  GtkWidget *log_app_text;
  GtkAdjustment *log_app_progress_adj;
  gint log_app_insertpoint;
} Console;

typedef struct {
  gchar *identity;
  GtkWidget *app;
  GtkWidget *status;
  GtkWidget *x;
  GArray *vboxen;
  gint columns;
  GtkWidget *vbox;
  gchar *server;
  gchar *console_font;
  gint console_scrollback;
  GtkWidget *config_app;
  GtkWidget **config_app_w;
  gint config_app_server_selection;
  gint config_app_console_selection;
  GtkWidget *prefs_app;
  GtkWidget *prefs_app_new_columns;
  GtkWidget *prefs_app_new_scrollback;
  GList *prefs_app_console_list;
  gchar **prefs_app_v;
  GtkWidget *prefs_app_font;
  ConcChannel *srv_chan;
  GConfEngine *gce;
  GList *consoles;
  ConcList *console_list;
  ConcList *server_list;
  gchar *buf;
  GtkRcStyle *activity_active;
  GtkRcStyle *activity_broken;
} Globals;
extern Globals *G;

extern void conc_load_prefs(void);
extern void conc_save_prefs(void);
extern void conc_preferences(GtkWidget *widget, gpointer data);
extern void conc_add_console(Console *c);
extern void conc_remove_console(Console *c);
extern void conc_update_consoles(void);
extern void conc_columns_new(gint newcols);
extern gint getid(gchar *p);
extern void conc_configure_edit_console(GtkButton *button,gpointer data);
extern void conc_configure(GtkWidget *widget, gpointer data);
extern void conc_configure_list_server_changed(void);
extern void conc_configure_list_console_changed(void);
